/**************************************************************************
*
* Filename:    PS4000con.c
*
* Copyright:   Pico Technology Limited 2010
*
* Author:      PT
*
* Description:
*   This is a console-mode program that demonstrates how to use the
*   PS4000 driver.
*
* Examples:
*    Collect a block of samples immediately
*    Collect a block of samples when a trigger event occurs
*    Collect a stream of data immediately
*    Collect a stream of data when a trigger event occurs
*    Set Signal Generator, using built in or custom signals
*
*	To build this application
*		Windows: set up a project for a 32-bit console mode application
*			 add this file to the project
*			 add PS4000.lib to the project (Microsoft C only)
*			 add ps4000Api.h and picoStatus.h to the project
*			 then build the project
*
*		Linux: gcc -lps4000 PS4000con.c -oPS4000con
*		       ./PS4000con
*
*
***************************************************************************/

//#ifdef WIN32
/* Headers for Windows */
#include "windows.h"
//#include <conio.h>
#include <stdio.h>

/* Definitions of PS4000 driver routines on Windows*/
#include "ps4000Api.h"

#define PREF4 __stdcall


//#endif

int cycles = 0;

#define BUFFER_SIZE 	1024
#define MAX_CHANNELS 4
#define QUAD_SCOPE 4
#define TRIPLE_SCOPE 3
#define DUAL_SCOPE 2
#define SEGMEM		10

typedef struct
{
	short DCcoupled;
	short range;
	short enabled;
}CHANNEL_SETTINGS;

typedef enum
{
	MODEL_NONE = 0,
	MODEL_PS4223 = 4223,
	MODEL_PS4224 = 4224,
	MODEL_PS4423 = 4423,
	MODEL_PS4424 = 4424,
	MODEL_PS4226 = 4226, 
	MODEL_PS4227 = 4227,
	MODEL_PS4262 = 4262
} MODEL_TYPE;

typedef struct tTriggerDirections
{
	enum enThresholdDirection channelA;
	enum enThresholdDirection channelB;
	enum enThresholdDirection channelC;
	enum enThresholdDirection channelD;
	enum enThresholdDirection ext;
	enum enThresholdDirection aux;
}TRIGGER_DIRECTIONS;

typedef struct tPwq
{
	struct tPwqConditions * conditions;
	short nConditions;
	enum enThresholdDirection direction;
	unsigned long lower;
	unsigned long upper;
	enum enPulseWidthType type;
}PWQ;  

typedef struct
{
	short							handle;
	MODEL_TYPE				model;
	PS4000_RANGE			firstRange;
	PS4000_RANGE			lastRange;
	unsigned char			signalGenerator;
	unsigned char			ETS;
	short							ChannelCount;
	CHANNEL_SETTINGS	channelSettings[MAX_CHANNELS];
	PS4000_RANGE			triggerRange;
}UNIT_MODEL;

unsigned long			timebase = 8;
short							oversample = 1;
BOOL							scaleVoltages = TRUE;

unsigned short inputRanges [PS4000_MAX_RANGES] = { 
10,
20,
50,
100,
200,
500,
1000,
2000,
5000,
10000,
20000,
50000};

short     		g_ready = FALSE;
long long 		g_times [PS4000_MAX_CHANNELS];
short     		g_timeUnit;
long      		g_sampleCount;
unsigned long g_startIndex;
short         g_autoStop;

short			g_trig = 0;
unsigned long	g_trigAt = 0;




int main(void)
{
	char ch;
	int i;
	PICO_STATUS status;
	UNIT_MODEL unit;
	struct tPwq pulseWidth;
	struct tTriggerDirections directions;

	printf("PS4000 driver example program\n");
	printf("\n\nOpening the device...\n");

	status = ps4000OpenUnit(&(unit.handle));
	printf("Handle: %d\n", unit.handle);
	
	if (status != PICO_OK && status != PICO_EEPROM_CORRUPT) 
	{
		printf("Unable to open device\n");
		printf("Error code : %d\n", (int)status);
		//while (!_kbhit());
		exit( 99); // exit program - nothing after this executes
	}


}
